# Release history

### 2.0.0
* Upgrade CDK support from v1 to v2.
* Upgrade GitHub pipelines checkout version from v2 to v3.
* Upgrade biomapas/cicd-full image version to 5.0.0.

### 1.0.0
* Upgrade dependencies to breaking versions.

### 0.1.2
* Make dependency range more strict.

### 0.1.1
* Add the ability to use a Bearer Token.
* Add JWT claims to authorizer output.

### 0.1.0
* Add property to expose authorization type for API Gateway APIs.

### 0.0.16
* Add more tests to handle completely broken jwt tokens like "aaa.bbb.ccc".

### 0.0.14
* Simplify logging with pytest.

### 0.0.13
* Update B.LambdaLayerCommon dependency.

### 0.0.12
* Add more integration tests.
* Update b_lambda_layer_common dependency.

### 0.0.11
* Add readme.

### 0.0.10
* Add tests.

### 0.0.9
* Enable caching.

### 0.0.8
* Fix testing configuration.

### 0.0.7
* Success! Authorizer can now successfully authorize tokens.

### 0.0.6
* First attempt to verify cognito user pool JWT token.

### 0.0.5
* Still work in progress. Requests and tests work. 
* Checking the actual access token - in progress.

### 0.0.3
* Work in progress. Added integration testing files.

### 0.0.1
* Initial build.
